agentle.mcp.sampling.request
============================

.. automodule:: agentle.mcp.sampling.request

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      AssistantMessage
      BaseModel
      ModelPreference
      SamplingRequest
      UserMessage
   